@@ -13,7 +13,7 @@
 #include <msql.h>
 #include "dbf.h"
 
-int	verbose = 0, upper = 0, lower = 0, create = 0;
+int	verbose = 0, upper = 0, lower = 0, create = 0, fieldlow = 0;
 char	primary[11];
 char	*host = NULL;
 char 	*dbase = "test";
@@ -83,7 +83,7 @@ int check_table(int sock, char *table) {
 void usage(void){
 		printf("dbf2msql %s\n", VERSION);
 		printf("usage:\tdbf2msql\t[-u | -l] [-h hostname] [-p primary key]\n");
-		printf("\t\t\t[-d dbase] [-t table] [-c] [-v] dbf-file\n");
+		printf("\t\t\t[-d dbase] [-t table] [-c] [-f] [-v[v]] dbf-file\n");
 }
 
 void do_create(int SQLsock, char *table, dbhead *dbh) {
@@ -110,6 +110,10 @@ void do_create(int SQLsock, char *table, dbhead *dbh) {
 		if ((strlen(query) != length)) {
                         strcat(query, ",");
                 }
+
+				if (fieldlow)
+					strtolower(dbh->db_fields[i].db_name);
+
                 strcat(query, dbh->db_fields[i].db_name);
                 switch(dbh->db_fields[i].db_type) {
 						case 'D':
@@ -267,8 +271,11 @@ int main(int argc, char **argv)
 
 	primary[0] = '\0';
 
-	while ((i = getopt(argc, argv, "lucvh:p:d:t:")) != EOF) {
+	while ((i = getopt(argc, argv, "flucvh:p:d:t:")) != EOF) {
 		switch (i) {
+			case 'f':
+				fieldlow=1;
+				break;
 			case 'v':
 				verbose++;
 				break;
